;; Generated package description from svg-lib.el  -*- no-byte-compile: t -*-
(define-package "svg-lib" "0.2.5" "SVG tags, progress bars & icons" '((emacs "27.1")) :commit "0486c9453449771bc3f5872f70bc5cb23580d0f4" :maintainer '("Nicolas P. Rougier" . "Nicolas.Rougier@inria.fr") :keywords '("svg" "icons" "tags" "convenience") :url "https://github.com/rougier/svg-lib")
